#ifndef NT2_INCLUDE_CONSTANTS_TEN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TEN_HPP_INCLUDED

#include <nt2/constant/include/constants/ten.hpp>

#endif
